==> ikaaro-0.50.4.tar.gz: ikaaro-0.50.4/ui/tiny_mce/plugins/style/langs/fr_dlg.js <==
tinyMCE.addI18n('fr.style_dlg',{
title:"\u00C9diter la feuille de style CSS",
apply:"Appliquer",
text_tab:"Texte",
background_tab:"Fond",
block_tab:"Bloc",
box_tab:"Bo\u00EEte",
border_tab:"Bordure",
list_tab:"Liste",
positioning_tab:"Positionement",
text_props:"Texte",
text_font:"Police",
text_size:"Taille",
text_weight:"Poids",
text_style:"Style",
text_variant:"Variante",
text_lineheight:"Hauteur de ligne",
text_case:"Casse",
text_color:"Couleur",
text_decoration:"D\u00E9coration",
text_overline:"surlign\u00E9",
text_underline:"soulign\u00E9",
text_striketrough:"barr\u00E9",
text_blink:"clignotant",
text_none:"aucun",
background_color:"Couleur de fond",
background_image:"Image de fond",
background_repeat:"R\u00E9p\u00E9ter",
background_attachment:"Attachement",
background_hpos:"Position horizontale",
background_vpos:"Position verticale",
block_wordspacing:"Espacement des mots ",
block_letterspacing:"Espacement des lettres",
block_vertical_alignment:"Alignement vertical",
block_text_align:"Alignement du texte",
block_text_indent:"Indentation du texte",
block_whitespace:"Fin de ligne",
block_display:"Affichage",
box_width:"Largeur",
box_height:"Hauteur",
box_float:"Flottant",
box_clear:"Vider",
padding:"Espacement",
same:"Identique pour tous",
top:"Haut",
right:"Droit",
bottom:"Bas",
left:"Gauche",
margin:"Marge",
style:"Style",
width:"Largeur",
height:"Hauter",
color:"Couleur",
list_type:"Type",
bullet_image:"Image de puce",
position:"Position",
positioning_type:"Type",
visibility:"Visibilit\u00E9",
zindex:"Z-index",
overflow:"D\u00E9bordement",
placement:"Placement",
clip:"Clip"
});

==> ikaaro-0.61.4.tar.gz: ikaaro-0.61.4/ui/tiny_mce/plugins/style/langs/fr_dlg.js <==
tinyMCE.addI18n('fr.style_dlg',{
title:"\u00C9diter la feuille de style",
apply:"Appliquer",
text_tab:"Texte",
background_tab:"Fond",
block_tab:"Bloc",
box_tab:"Bo\u00EEte",
border_tab:"Bordure",
list_tab:"Liste",
positioning_tab:"Positionnement",
text_props:"Texte",
text_font:"Police",
text_size:"Taille",
text_weight:"Gras",
text_style:"Style",
text_variant:"Variante",
text_lineheight:"Hauteur de ligne",
text_case:"Casse",
text_color:"Couleur",
text_decoration:"D\u00E9coration",
text_overline:"ligne au-dessus",
text_underline:"soulign\u00E9",
text_striketrough:"barr\u00E9",
text_blink:"clignotant",
text_none:"aucun",
background_color:"Couleur de fond",
background_image:"Image de fond",
background_repeat:"R\u00E9p\u00E9ter",
background_attachment:"Attachement",
background_hpos:"Position horizontale",
background_vpos:"Position verticale",
block_wordspacing:"Espacement des mots ",
block_letterspacing:"Espacement des lettres",
block_vertical_alignment:"Alignement vertical",
block_text_align:"Alignement du texte",
block_text_indent:"Indentation du texte",
block_whitespace:"Fin de ligne",
block_display:"Affichage",
box_width:"Largeur",
box_height:"Hauteur",
box_float:"Flottant",
box_clear:"Vider",
padding:"Espacement",
same:"Identique pour tous",
top:"Haut",
right:"Droit",
bottom:"Bas",
left:"Gauche",
margin:"Marge",
style:"Style",
width:"Largeur",
height:"Hauteur",
color:"Couleur",
list_type:"Type",
bullet_image:"Image de puce",
position:"Position",
positioning_type:"Type",
visibility:"Visibilit\u00E9",
zindex:"Z-index",
overflow:"D\u00E9bordement",
placement:"Placement",
clip:"Clip"
});
